@@ -4,8 +4,8 @@ import fdsreader.export
 
 
 def main():
-    base_path = r"C:\Users\ias7_188\RiderProjects\VRSmokeVis"
-    case = ""  # "Apartment"
+    base_path = "."
+    case = "Apartment"
     sim = fds.Simulation(os.path.join(base_path, "fds_data", case))
 
     for obst in sim.obstructions:
