@@ -150,7 +150,7 @@ class Simulation:
             self._particles = list()
             self._evacs = list()
             self._geom_data = list()
-            self._meshes = list()
+            self._meshes: List[Mesh] = list()
             self._devices = dict()
 
             self.profiles: Dict[str, Profile] = dict()
@@ -206,9 +206,7 @@ class Simulation:
         with open(self.smv_file_path, 'r') as smv_file:
             for line in smv_file:
                 keyword = line.strip()
-                if keyword == "VERSION":
-                    self.fds_version = smv_file.readline().strip()
-                elif keyword == "FDSVERSION":
+                if keyword == "VERSION" or keyword == "FDSVERSION":
                     self.fds_version = smv_file.readline().strip()
                 elif keyword == "CHID":
                     self.chid = smv_file.readline().strip()
@@ -369,7 +367,7 @@ class Simulation:
 
         obst_index, time = smv_file.readline().split()
         time = float(time)
-        subobst = self._subobstructions[mesh][int(obst_index) - 1]
+        subobst = self._subobstructions[mesh.id][int(obst_index) - 1]
 
         if "HIDE_OBST" in line[0]:
             subobst._hide(time)
